@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use strictures 2;
 use Array::Circular ();
@@ -251,7 +251,7 @@ MIDI::RtController::Filter::Tonal - Tonal RtController filters
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
@@ -405,9 +405,11 @@ not.
 
 =head2 pedal_tone
 
-  pedal, $note, $note + 7
+Play a series of notes in succession by B<delay>.
 
-Where the B<pedal> is the object attribute.
+Default: C<pedal, $note, $note + 7 semitones>
+
+Where B<pedal> is the object attribute.
 
 =head2 chord_tone
 
